@@ -47,6 +47,9 @@ class Z2Logger:
     def error(self, text, exc_info=None):
         zLOG(ident, ERROR, text, error=exc_info)
 
+    def __call__(self, text):
+        self.info(text)
+
 def Logger():
     """ Logger factory """
     
