@@ -19,12 +19,15 @@ country_codes = {
     'fi' : 'finnish', 
     'fr' : 'french', 
     'de' : 'german', 
+    'hu' : 'hungarian', 
     'it' : 'italian', 
     'no' : 'norwegian', 
     'pt' : 'portuguese', 
+    'ro' : 'romanian',
     'ru' : 'russian', 
     'es' : 'spanish', 
-    'sv' : 'swedish'
+    'sv' : 'swedish',
+    'tr' : 'turkish',
 }
 
 availableStemmers = stemmer.availableStemmers()
