@@ -11,7 +11,7 @@
 """
 index unit tests
 
-$Id: testIndex.py 1838 2007-04-15 12:55:55Z ajung $
+$Id: testIndex.py 1881 2007-07-14 10:59:34Z ajung $
 """
 
 import os
@@ -393,10 +393,8 @@ class FunctionalTest(TextIndexNGTestCase):
 
             num = random.choice(range(1, 200))
             if random.randint(0, 1) == 0:
-                print 'adding', num
                 index.unindex_object(num)
             else:
-                print 'removing', num
                 self._addDoc(index, num) 
 
             result = self.check_storage(index)
