@@ -9,20 +9,24 @@
 # info@zopyx.com, www.zopyx.com 
 ################################################################
 
-from Products.PloneTestCase import PloneTestCase
+import unittest
 
-import os, sys
-import tempfile, glob
+try:
+    from Products.PloneTestCase import PloneTestCase
+    PloneTestCase.installProduct('Five')
+    PloneTestCase.installProduct('CMFPlone')
+    PloneTestCase.installProduct('TextIndexNG3')
 
-PloneTestCase.installProduct('Five')
-PloneTestCase.installProduct('CMFPlone')
-PloneTestCase.installProduct('TextIndexNG3')
-
-# setup a new Plohn site    
-PloneTestCase.setupPloneSite(products=('TextIndexNG3', ))
+    # setup a new Plohn site    
+    PloneTestCase.setupPloneSite(products=('TextIndexNG3', ))
+    PTC = PloneTestCase.PloneTestCase
+    _PLONE_INSTALLED = True
+except ImportError:
+    PTC = object
+    _PLONE_INSTALLED = False
 
 
-class PloneTests(PloneTestCase.PloneTestCase):
+class PloneTests(PTC):
 
     def afterSetUp(self):
         membership = self.portal.portal_membership
@@ -38,10 +42,10 @@ class PloneTests(PloneTestCase.PloneTestCase):
         self.assertEqual(indexes['Title'].meta_type, 'TextIndexNG3')
 
 
-
 def test_suite():
-    from unittest import TestSuite, makeSuite
-    suite = TestSuite()
-    suite.addTest(makeSuite(PloneTests))
-    return suite
-
+    s = unittest.TestSuite()
+    if _PLONE_INSTALLED:
+        s.addTest(unittest.makeSuite(PloneTests))
+    else:
+        print 'Skipped Plone setup tests.'
+    return s
